==> bonita-java-client-1.0.0-sources.jar: org/bonitasoft/web/client/api/MessageApi.java <==
/** 
 * Copyright (C) 2023 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2.0 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package org.bonitasoft.web.client.api;

import org.bonitasoft.web.client.invoker.ApiClient;
import org.bonitasoft.web.client.model.ApiResponse;
import org.bonitasoft.web.client.model.Message;

import feign.*;

@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen")
public interface MessageApi extends ApiClient.Api {

    /**
     * Send BPM message events
     * Use this resource to send BPM message events. Message events are caught by processes using &#x60;catch message event&#x60; flow nodes (Start, intermediate,
     * boundary or receive tasks).
     * 
     * @param body A Message event (required)
     */
    @RequestLine("POST /API/bpm/message")
    @Headers({
            "Content-Type: application/json",
            "Accept: application/json",
    })
    void createMessage(Message body);

    /**
     * Send BPM message events
     * Similar to <code>createMessage</code> but it also returns the http response headers .
     * Use this resource to send BPM message events. Message events are caught by processes using &#x60;catch message event&#x60; flow nodes (Start, intermediate,
     * boundary or receive tasks).
     * 
     * @param body A Message event (required)
     */
    @RequestLine("POST /API/bpm/message")
    @Headers({
            "Content-Type: application/json",
            "Accept: application/json",
    })
    ApiResponse<Void> createMessageWithHttpInfo(Message body);

}

==> bonita-java-client-2.0.0-sources.jar: org/bonitasoft/web/client/api/MessageApi.java <==
/** 
 * Copyright (C) 2024 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2.0 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package org.bonitasoft.web.client.api;

import org.bonitasoft.web.client.invoker.ApiClient;
import org.bonitasoft.web.client.model.ApiResponse;
import org.bonitasoft.web.client.model.Message;

import feign.*;

@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", comments = "Generator version: 7.8.0")
public interface MessageApi extends ApiClient.Api {

    /**
     * Send BPM message events
     * Use this resource to send BPM message events. Message events are caught by processes using &#x60;catch message event&#x60; flow nodes (Start, intermediate,
     * boundary or receive tasks).
     * 
     * @param body A Message event (required)
     */
    @RequestLine("POST /API/bpm/message")
    @Headers({
            "Content-Type: application/json",
            "Accept: application/json",
    })
    void createMessage(Message body);

    /**
     * Send BPM message events
     * Similar to <code>createMessage</code> but it also returns the http response headers .
     * Use this resource to send BPM message events. Message events are caught by processes using &#x60;catch message event&#x60; flow nodes (Start, intermediate,
     * boundary or receive tasks).
     * 
     * @param body A Message event (required)
     */
    @RequestLine("POST /API/bpm/message")
    @Headers({
            "Content-Type: application/json",
            "Accept: application/json",
    })
    ApiResponse<Void> createMessageWithHttpInfo(Message body);

}
